/**
 * MENU 菜单数组对象格式:
 *
 * name: { String } 菜单展示名称
 * route: { Object } 路由对象
 *    name: { String } 路由名, 在 routes 中定义
 * children: { Array } 子菜单, 每项为一个对象
 *    childrenObj: {
 *      name: { String } 菜单展示名称, 同父菜单 name
 *      route: { Object } 路由对象, 同父菜单 route
 *      originalUrl: { String } 锐特包含功能权限的菜单路径链接标识
 *    }
 * */
const MENU = [
  {
    name: '首页',
    iconClass: 'icon-shouye_',
    route: { name: 'home' }
  },
  {
    name: '入库管理',
    iconClass: 'icon-xiazai',
    route: { name: 'stockIn' },
    children: [
      {
        name: '预收货通知',
        route: { name: 'preReceiving' },
        originalUrl: 'InboundAsnList',
      },
      {
        name: '收货',
        route: { name: 'collectGoods' },
        originalUrl: 'InboundRcvList',
      },
      {
        name: '上架',
        route: { name: 'putaway' },
        originalUrl: 'InboundPutawayList',
      },
      {
        name: '质检登记',
        route: { name: 'quality' },
        originalUrl: 'InboundQcRegisterList',
      },
      {
        name: '质检处理',
        route: { name: 'manage' },
        originalUrl: 'InboundQcHandleList',
      },

    ],
  },
  {
    name: '出库管理',
    iconClass: 'icon-shangchuan',
    route: { name: 'stockOut' },
    children: [
      {
        name: '发运订单',
        route: { name: 'sendOrder' },
        originalUrl: 'OutboundSoOrderList',
      },
      {
        name: '拣货',
        route: { name: 'picking' },
        originalUrl: 'OutboundPkTaskList',
      },
      {
        name: '发货',
        route: { name: 'deliverGoods' },
        originalUrl: 'OutboundShippmentList',
      },
      {
        name: '装车单',
        route: { name: 'loadingList' },
        originalUrl: 'OutboundLoadOrderList',
      }
    ],
  },
  {
    name: '库存管理',
    iconClass: 'icon-iconfontzhizuobiaozhun0247',
    route: { name: 'inventory' },
    children: [
      {
        name: '库存盘点',
        route: { name: 'count' },
        originalUrl: 'InventoryCountList',
      },
      {
        name: '库存调整单',
        route: { name: 'adjustment' },
        originalUrl: 'InventoryAdOrderList',
      },
      {
        name: '库存移动',
        route: { name: 'movement' },
        originalUrl: 'InventoryMovementList',
      },
      {
        name: '库存移动单',
        route: { name: 'mvOrder' },
        originalUrl: 'InventoryMvOrderList',
      },
      {
        name: '移动任务',
        route: { name: 'movementTask' },
        originalUrl: 'InventoryMvTaskList',
      },
      {
        name: '货权转移单',
        route: { name: 'ownerTransfer' },
        originalUrl: 'InventoryTfOrderList',
      },
      {
        name: '库存冻结',
        route: { name: 'block' },
        originalUrl: 'InventoryHoldList',
      },
      {
        name: '库内业务',
        route: { name: 'insideBusiness' },
        originalUrl: 'insideBusiness',
      },
    ],
  },
  {
    name: '库存查询',
    iconClass: 'icon-icon_search',
    route: { name: 'inventoryQuery' },
    children: [
      {
        name: '条件查询',
        route: { name: 'queryByTerms' },
        originalUrl: 'InventoryQueryByOwnerList',
      },
      {
        name: '库存交易',
        route: { name: 'transaction' },
        originalUrl: 'InventoryActTranList',
      },
      {
        name: '冻结记录查询',
        route: { name: 'blockLog' },
        originalUrl: 'InventoryActHoldList',
      },
    ]
  },
  {
    name: '仓库基础数据',
    iconClass: 'icon-xianshi_bi',
    route: { name: 'warehouseBasic' },
    children: [
      {
        name: '区域',
        route: { name: 'libraryRegion' },
        originalUrl: 'BasicdataAreaList',
      },
      {
        name: '库区',
        route: { name: 'libraryArea' },
        originalUrl: 'BasicdataZoneList',
      },
      {
        name: '库位',
        route: { name: 'libraryPlace' },
        originalUrl: 'BasicdataLocList',
      },
      {
        name: '商品',
        route: { name: 'libraryGoods' },
        originalUrl: 'BasicdataSkuList',
      },
      {
        name: '批次属性',
        route: { name: 'libraryBatch' },
        originalUrl: 'BasicdataLotList',
      },
      {
        name: '质检项',
        route: { name: 'qcItems' },
        originalUrl: 'BasicdataQcItemList',
      },
      {
        name: '车辆管理',
        route: { name: 'vehicle' },
        originalUrl: 'basicdataVehicle',
      },
    ]
  },
  {
    name: '仓库策略管理',
    iconClass: 'icon-shezhi',
    route: { name: 'strategy' },
    children: [
      {
        name: '质检规则',
        route: { name: 'qcRules' },
        originalUrl: 'BasicdataRuleQcList',
      },
    ]
  },
  {
    name: '加工管理',
    iconClass: 'icon-banshou',
    route: { name: 'machining' },
    children: [
      {
        name: '组合件',
        route: { name: 'cdWhBomList' },
        originalUrl: 'CdWhBomList'
      },
      {
        name: '加工订单',
        route: { name: 'wmKitOrderList' },
        originalUrl: 'WmKitOrderList'
      },
      {
        name: '加工拣货',
        route: { name: 'kitTaskPickingList' },
        originalUrl: 'KitTaskPickingList'
      },
      {
        name: '加工确认',
        route: { name: 'kitBomKitConfirmList' },
        originalUrl: 'KitBomKitConfirmList'
      },
      {
        name: '加工上架',
        route: { name: 'kitTaskPaList' },
        originalUrl: 'KitTaskPaList'
      },
    ]
  },
  {
    name: '计费管理',
    iconClass: 'icon-meiyuan-copy',
    route: { name: 'charging' },
    children: [
      {
        name: '费率组',
        route: { name: 'costGroup' },
        originalUrl: 'ChargeRateGroupList'
      },
      {
        name: '计费合同',
        route: { name: 'contract' },
        originalUrl: 'ChargeContractList'
      },
      {
        name: '费用维护',
        route: { name: 'maintain' },
        originalUrl: 'ChargeFeeList'
      },
      {
        name: '费用汇总-按订单',
        route: { name: 'order' },
        originalUrl: 'FeeSummaryOrderList'
      },
      {
        name: '费用汇总-按客户',
        route: { name: 'customer' },
        originalUrl: 'FeeSummaryCustomerList'
      },
      {
        name: '费用汇总-按类别',
        route: { name: 'category' },
        originalUrl: 'FeeSummaryTypeList'
      }
    ]
  },
  {
    name: '月台管理',
    iconClass: 'icon-guidao',
    route: { name: 'platform' },
    children: [
      {
        name: '月台',
        route: { name: 'dockBasicdataList' },
        originalUrl: 'DockBasicdataList'
      },
      {
        name: '月台调度',
        route: { name: 'dockDispatchList' },
        originalUrl: 'DockDispatchList'
      }
    ]
  },
  {
    name: '越库管理',
    iconClass: 'icon-zhuanhuan',
    route: { name: 'crossDock' },
    children: [
      {
        name: '生成越库任务',
        route: { name: 'crossDockTaskGenerateList' },
        originalUrl: 'CrossDockTaskGenerateList'
      },
      {
        name: '执行越库任务',
        route: { name: 'crossDockTaskExcuteList' },
        originalUrl: 'CrossDockTaskExcuteList'
      }
    ]
  },
  {
    name: '仓储作业报表',
    iconClass: 'icon-duidie',
    route: { name: 'StorageTasks' },
    children: [
      {
        name: '入库日报表',
        route: { name: 'reportInDailyList' },
        originalUrl: 'ReportInDailyList'
      },
      {
        name: '出库日报表',
        route: { name: 'reportOutDailyList' },
        originalUrl: 'ReportOutDailyList'
      },
      {
        name: '装车单明细报表',
        route: { name: 'reportLdDetailList' },
        originalUrl: 'ReportLdDetailList'
      },
      {
        name: '库存报表',
        route: { name: 'reportInvList' },
        originalUrl: 'ReportInvList'
      },
      {
        name: '库存移动报表',
        route: { name: 'reportMvOrderList' },
        originalUrl: 'ReportMvOrderList'
      },
      {
        name: '库存转移报表',
        route: { name: 'reportTfOrderList' },
        originalUrl: 'ReportTfOrderList'
      },
      {
        name: '库存调整报表',
        route: { name: 'reportAdOrderList' },
        originalUrl: 'ReportAdOrderList'
      },
      {
        name: '取消预配日志报表',
        route: { name: 'logCancelPreAlloctionList' },
        originalUrl: 'LogCancelPreAlloctionList'
      },
      {
        name: '取消分配日志报表',
        route: { name: 'logCancelAlloctionList' },
        originalUrl: 'LogCancelAlloctionList'
      },
      {
        name: '上架库位对照表',
        route: { name: 'reportLocPADeffList' },
        originalUrl: 'ReportLocPADeffList'
      },
    ]
  },
  {
    name: '汇总统计报表',
    iconClass: 'icon-zhuxingtu',
    route: { name: 'summaryReport' },
    children: [
      {
        name: '进出存合并报表',
        route: { name: 'combine' },
        originalUrl: 'ReportCombineList',
      },
      {
        name: '入库量趋势报表',
        route: { name: 'stockInTrend' },
        originalUrl: 'ReportInTrendList',
      },
      {
        name: '出库量趋势报表',
        route: { name: 'stockOutTrend' },
        originalUrl: 'ReportOutTrendList',
      },
      {
        name: '入库作业报表',
        route: { name: 'stockInBusiness' },
        originalUrl: 'ReportInBusinessList',
      },
      {
        name: '出库作业报表',
        route: { name: 'stockOutBusiness' },
        originalUrl: 'ReportOutBusinessList',
      },
      {
        name: '接单未收明细报表',
        route: { name: 'noRcvAsn' },
        originalUrl: 'ReportNoReceiveAsnDetailList',
      },
      {
        name: '接单未发明细报表',
        route: { name: 'noSpSo' },
        originalUrl: 'ReportNoShippingSoDetailList',
      },
      {
        name: '库存周转率报表',
        route: { name: 'rotationRate' },
        originalUrl: 'ReportRotationRateList',
      },
      {
        name: '标准库龄报表',
        route: { name: 'standardWhAge' },
        originalUrl: 'ReportStandardWhAgeList',
      },
      {
        name: '空库位统计报表',
        route: { name: 'emptyLoc' },
        originalUrl: 'ReportEmptyLocList',
      },
      {
        name: '按托盘统计库容报表',
        route: { name: 'capacityByTraceId' },
        originalUrl: 'ReportEmptyLocList',
      },
    ]
  },
  {
    name: '监控预警',
    iconClass: 'icon-xiaofangjingling',
    route: { name: 'monitor' },
    children: [
      {
        name: '入出库作业统计报表',
        route: { name: 'reportOwnerInOutList' },
        originalUrl: 'ReportOwnerInOutList'
      },
      {
        name: '库位使用率',
        route: { name: 'reportLocUsageRateList' },
        originalUrl: 'ReportLocUsageRateList'
      },
      {
        name: '保质期预警',
        route: { name: 'reportShelfLifeWarningList' },
        originalUrl: 'ReportShelfLifeWarningList'
      },
      {
        name: '任务监控',
        route: { name: 'reportTaskMonitorList' },
        originalUrl: 'ReportTaskMonitorList'
      },
      {
        name: '库存预警',
        route: { name: 'reportInvWarnList' },
        originalUrl: 'ReportInvWarnList'
      },
    ]
  },
  {
    name: '企业级管理',
    route: { name: 'enterprise' },
    iconClass: 'icon-guanli',
    children: [
      {
        name: '多仓作业统计报表',
        route: { name: 'warehousesBusiness' },
        originalUrl: 'EnterpriseReportBusinessOfMultiWhList',
      },
      {
        name: '多货主作业统计报表',
        route: { name: 'ownersBusiness' },
        originalUrl: 'EnterpriseReportBusinessOfMultiOwnerList',
      },
      {
        name: '多仓入库作业报表',
        route: { name: 'warehousesStockIn' },
        originalUrl: 'EnterpriseReportInBusinessOfMultiWhList',
      },
      {
        name: '多仓出库作业报表',
        route: { name: 'warehousesStockOut' },
        originalUrl: 'EnterpriseReportOutBusinessOfMultiWhList',
      },
      {
        name: '多仓库存报表',
        route: { name: 'warehousesInventory' },
        originalUrl: 'EnterpriseReportInvOfMultiWhList',
      },
      {
        name: '多仓库容监控',
        route: { name: 'warehousesCapacity' },
        originalUrl: 'EnterpriseReportLocOccupancyRateList',
      },
    ]
  },
  {
    name: '视频监控',
    iconClass: 'icon-jiankong',
    route: { name: 'monitor' },
    children: [
      {
        name: '摄像头管理',
        route: { name: 'home' },
        originalUrl: 'cameramanager',
      },
      {
        name: '仓库监控',
        route: { name: 'home' },
        originalUrl: 'videocontrol',
      },
    ]
  },
  {
    name: '库存可视化管理',
    iconClass: 'icon-keshihua1',
    route: { name: 'graphical' },
    children: [
      {
        name: '库存图形可视化',
        route: { name: 'graphicalViewer' },
        originalUrl: 'InventoryViewer'
      },
      {
        name: '库存图形可视化配置',
        route: { name: 'graphicalConfig' },
        originalUrl: 'InventoryViewerConfig'
      }
    ]
  }

]

export default MENU
